# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-12-20 04:04
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoevents', '0002_event_event_version'),
    ]

    operations = [
        migrations.AlterField(
            model_name='event',
            name='stored_entity_id',
            field=models.CharField(db_column='_stored_entity_id', db_index=True, max_length=255),
        ),
    ]
